@@ -59,13 +59,13 @@ def init(create_window=True, image_size=None):
         glfw.make_context_current(window)
 
     # compile shaders
-    shader_dir = os.path.join(os.path.dirname(__file__))+"/shaders"
-    cs_butterfly = Shader(shader_dir + "/butterflytexture.glsl")
-    cs_cosft = Shader(shader_dir + "/cos_filter.glsl")
-    cs_fft = Shader(shader_dir + "/fft.glsl")
-    cs_fft_pi = Shader(shader_dir + "/fft_inversion_permutation.glsl")
-    cs_multiply = Shader(shader_dir + "/fft_phase_correlation.glsl")
-    cs_resample = Shader(shader_dir + "/resample_image.glsl")
+    shader_dir = os.path.join(os.path.dirname(__file__))+"\\shaders\\"
+    cs_butterfly = Shader(shader_dir + "\\butterflytexture.glsl")
+    cs_cosft = Shader(shader_dir + "\\cos_filter.glsl")
+    cs_fft = Shader(shader_dir + "\\fft.glsl")
+    cs_fft_pi = Shader(shader_dir + "\\fft_inversion_permutation.glsl")
+    cs_multiply = Shader(shader_dir + "\\fft_phase_correlation.glsl")
+    cs_resample = Shader(shader_dir + "\\resample_image.glsl")
 
     # create textures with set_image_size
     if image_size is not None:
